import { isFunction } from "@/utils/types.js"
import Toast from "@/lib/toast/index.js"
import store from "@/store/index.js"
/**
 * @desc 倒计时
 * @param { Number } num 倒计时时间
 * @param { Functiom } cb 回调 
 */
export function timerFn(num = 60, cb) {
	let timer = setInterval(() => {
		cb && isFunction(cb) && cb(num)
		num --
		if(num < 0) {
			clearInterval(timer)
			timer = null
			return
		}
	}, 1000)
}

/**
 * @desc 节流函数 cv的
 * @param {Function} callback 回调函数
 * @param {Number} wait 间隔时间
 * @return {Function} 节流函数
 */
export function throttle(callback, wait = 3000) {
    let timer = null;
    let startTime;
    return function () {
        const ctx = this;
        const args = arguments;
        const now = +new Date();
        if (startTime && now < startTime + wait) {
            clearTimeout(timer);
            timer = setTimeout(function () {
                startTime = now;
                callback.apply(ctx, args);
            }, wait);
        } else {
            startTime = now;
            callback.apply(ctx, args);
        }
    }
}

/**
 * @desc 防抖函数  cv的
 * @param {需要防抖的函数} func
 * @param {延迟时间} wait
 * @param {是否立即执行} immediate
 */
export function debounce(func, wait = 1000, immediate = true) {
  let timeout
  return function(...args) {
    let context = this
    if (timeout) clearTimeout(timeout)

    if (immediate) {
      let callNow = !timeout
      timeout = setTimeout(function() {
        timeout = null
      }, wait)
      if (callNow) func.apply(context, args)
    } else {
      timeout = setTimeout(function() {
        func.apply(context, args)
      }, wait)
    }
  }
}

/**
 * 联系老板 
 */
export function makePhoneCall() {
	const storeInfo = store.state.user.storeInfo
	if(storeInfo && storeInfo.shop_tel) {
		const phoneNumber = storeInfo.shop_tel
		uni.showModal({
			content: `是否拨打${phoneNumber}`,
			success: res => {
				if(res.confirm) {
					uni.makePhoneCall({
						phoneNumber
					})
				} 
			}
		})
	}
}
